@@ -1,24 +1,23 @@
 from IPython.display import display, HTML
 
 class Color():
-    """ Class to color table
-            
     """
-    
-    
-    def __init__(self, DataFrame,colorName='lightgrey'):
-
-        """Function for different color
+        Function to color dataframe
         
         Args: 
-            (DataFrame,ColorName(Optional))
+            Color(DataFrame,ColorName(Optional))
 
             ex. Color(df,'red')
         
         Returns: 
             dataframe: colored
     
-        """
+    """
+    
+    
+    def __init__(self, DataFrame,colorName='lightgrey'):
+
+        
 
         self.df = DataFrame
         self.colorName=colorName
